fonttools: Tools to manipulate font files
=========================================

Description
-----------

Tools to manipulate font files

License
-------

MIT

Upstream Contact
----------------

https://pypi.org/project/fonttools/

